<?php
/**
 * NOTICE OF LICENSE
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author    Tunisie SMS
 *  @copyright 2015-2023 Inwave
 *  @license   GNU General Public License version 2
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

include_once(dirname(__FILE__) . '/class/SHOutils.php');
include_once(dirname(__FILE__) . '/controllers/admin/AdminSHAdmin.php');

class TunisieSMS extends Module
{

    public function __construct()
    {
        //$this->module_key = '9ea5b0405d787be83a4aff15fe8379cv';
        $this->name = 'tunisiesms';
        $this->tab = 'administration';
        $this->version = '24.02.13.0';
        $this->author = 'TunisieSMS.tn';
		
        $this->need_instance = 0;
        //$this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('Module Presta-Tunisie SMS');
        $this->description = $this->l('Découvrez  notre module API SMS pour Prestashop qui vous permet d’envoyer de manière automatique des SMS à différentes étapes du parcours de paiement / livraison des commandes de vos clients.Le module permet de personnaliser les messages avec des fonctionnalités d’envoi automatique, ainsi qu’une garantie de remise des messages SMS envoyés depuis votre espace Prestashop.');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        $this->context->smarty->assign("templates_dir", _PS_MODULE_DIR_ . 'tunisiesms/views/templates');
        if (!Configuration::get('TUNISIE_SMS_NAME')) {
            $this->warning = $this->l('No name provided');
        }
        $this->tabs = array(
            "AdminSHConfiguration" => array(
                "label" => $this->l('Configure'),
                "icon" => "settings",
            ),
            "AdminSHEnvoyerSMS" => array(
                "label" => $this->l('Send SMS'),
                "icon" => "message",
            ),
            "AdminSHOutbox" => array(
                "label" => $this->l('Outbox'),
                "icon" => "markunread"
            ),
            "AdminSHConfig" => array(
                "label" => $this->l('Admin notifications'),
                "icon" => "settings"
            ),
            // "AdminSHEnvoyerEmail" => array(
            //     "label" => $this->l('Send Emails'),
            //     "icon" => "mail_outline",
            // ),
            // "AdminSHConfigurationEmail" => array(
            //     "label" => $this->l('Configure Automatic Emails'),
            //     "icon" => "add_alert",
            // ),
        );
        $this->addRessources();
    }

    public function install()
    {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }

        if (!parent::install()
        || !$this->installHooks()
        || !$this->installTabs()
        || !$this->installDB()
        || !$this->installDBEtatSMS()) {
            return false;
        }

        return true;
    }

    public function installConfiguration()
    {
        $configuration = array(
            "sms_gateway" => "",
            "cle_api" => "",
            "sms_expediteur" => "",
            "type" => "premium",
            "sms_taille" => "1",
            // "sms_etat_annule" => false,
            // "sms_etat_annule_message" => "Votre commande a été annulée. Pour plus d'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet.",
            // "sms_etat_en_cours" => false,
            // "sms_etat_en_cours_message" => "Votre commande est en cours de préparation. Pour plus d'informations et suivre votre commande, rendez-vous directement sur notre site internet.",
            // "sms_etat_expedie" => false,
            // "sms_etat_expedie_message" => "Votre commande vient d'être expédiée. Pour plus d'informations et suivre votre commande, rendez-vous directement sur notre site internet.",
            // "sms_etat_livre" => false,
            // "sms_etat_livre_message" => "Votre commande vous a été livrée. Pour effectuer une nouvelle commande, rendez-vous directement sur notre site internet.",
            // "sms_etat_rembourse" => false,
            // "sms_etat_rembourse_message" => "Votre commande vient de vous être remboursée. Pour plus d'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet.",

            "email_expediteur" => "",
            "email_nom_expediteur" => "",
            "email_reponse" => "",
            "email_sujet" => "",
            "email_etat_annule" => false,
            "email_etat_annule_message" => "Votre commande a été annulée. Pour plus d'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet.",
            "email_etat_en_cours" => false,
            "email_etat_en_cours_message" => "Votre commande est en cours de préparation. Pour plus d'informations et suivre votre commande, rendez-vous directement sur notre site internet.",
            "email_etat_expedie" => false,
            "email_etat_expedie_message" => "Votre commande vient d'être expédiée. Pour plus d'informations et suivre votre commande, rendez-vous directement sur notre site internet.",
            "email_etat_livre" => false,
            "email_etat_livre_message" => "Votre commande vous a été livrée. Pour effectuer une nouvelle commande, rendez-vous directement sur notre site internet.",
            "email_etat_rembourse" => false,
            "email_etat_rembourse_message" => "Votre commande vient de vous être remboursée. Pour plus d'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet."
        );

        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS(
            'SELECT osl.id_order_state, osl.name
                FROM '._DB_PREFIX_.'order_state_lang osl                        
                WHERE osl.`id_lang` = 1'        
        );

        foreach ($result as $row) 
        {
            $config["sms_etat_" . $row['id_order_state']] =  false ;
            $config["sms_etat_" . $row['id_order_state']. "_message"] =  "Votre commande vient d'être ". $row['name']."." ;
        }      



        return Configuration::updateValue('TUNISIE_SMS_NAME', "TunisieSMS") && Configuration::updateValue('TUNISIE_SMS_SETTINGS', serialize($configuration));
    }

    public function installHooks()
    {
        return  $this->registerHook('actionOrderStatusUpdate') &&
                $this->registerHook('actionCustomerAccountAdd') &&
                $this->registerHook('newOrder') &&
                $this->registerHook('authentication') ;
                
    }

    public function installDB()
    {
        return Db::getInstance()->execute(
            'CREATE TABLE IF NOT EXISTS '._DB_PREFIX_.'tunisiesms_configuration (champs VARCHAR(255) NOT NULL UNIQUE, valeur TEXT NOT NULL) ENGINE=InnoDB DEFAULT CHARSET=utf8 ') 
        && Db::getInstance()->execute(
            'CREATE TABLE IF NOT EXISTS '._DB_PREFIX_.'tunisiesms_sms_send (id   INT(11) NOT NULL AUTO_INCREMENT PRIMARY KEY, sms LONGTEXT NOT NULL, sender LONGTEXT NOT NULL, recipient LONGTEXT NOT NULL, date datetime NOT NULL, response LONGTEXT NOT NULL,status LONGTEXT NOT NULL)') 
        && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="id_export", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="nom_export", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="id_export_newsletter", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="nom_export_newsletter", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="cle_api", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_expediteur", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_type", valeur = "premium"'
        )&& Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_gateway", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_taille", valeur = "1"'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_destinataires", valeur = ""'
        )  && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_authenticate", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_authenticate_message", valeur = "Une nouvelle de connexion est effectuée."'
        )&& Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_create_account", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_create_account_message", valeur = "Un nouveau compte a été crée."'
        )&& Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_new_order", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_new_order_message", valeur = "Une nouvelle commande %COMMANDE% a été crée."'
        )&& Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_expediteur", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_nom_expediteur", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_reponse", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_sujet", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_annule", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_annule_message", valeur = "Votre commande a été annulée. Pour plus d\'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_en_cours", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_en_cours_message", valeur = "Votre commande est en cours de préparation. Pour plus d\'informations et suivre votre commande, rendez-vous directement sur notre site internet."'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_expedie", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_expedie_message", valeur = "Votre commande vient d\'être expédiée. Pour plus d\'informations et suivre votre commande, rendez-vous directement sur notre site internet."'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_livre", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_livre_message", valeur = "Votre commande vous a été livrée. Pour effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_rembourse", valeur = ""'
        ) && Db::getInstance()->execute(
            'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_rembourse_message", valeur = "Votre commande vient de vous être remboursée. Pour plus d\'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        ) ;
        
        // return Db::getInstance()->execute(
        //     'CREATE TABLE IF NOT EXISTS '._DB_PREFIX_.'tunisiesms_configuration (champs VARCHAR(255) NOT NULL UNIQUE, valeur LONGTEXT NOT NULL)'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="id_export", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="nom_export", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="id_export_newsletter", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="nom_export_newsletter", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="cle_api", valeur = ""'
        // )&& Db::getInstance()->execute(
        //         'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_gateway", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_expediteur", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_destinataires", valeur = ""'
        // )  && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_authenticate", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_authenticate_message", valeur = "Une nouvelle de connexion est effectuée."'
        // )&& Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_create_account", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_create_account_message", valeur = "Un nouveau compte a été crée."'
        // )&& Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_new_order", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="adm_sms_new_order_message", valeur = "Une nouvelle commande %COMMANDE% a été crée."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_type", valeur = "premium"'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_taille", valeur = "1"'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_expediteur", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_nom_expediteur", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_reponse", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_sujet", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_annule", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_annule_message", valeur = "Votre commande a été annulée. Pour plus d\'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_en_cours", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_en_cours_message", valeur = "Votre commande est en cours de préparation. Pour plus d\'informations et suivre votre commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_expedie", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_expedie_message", valeur = "Votre commande vient d\'être expédiée. Pour plus d\'informations et suivre votre commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_livre", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_livre_message", valeur = "Votre commande vous a été livrée. Pour effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_rembourse", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="email_etat_rembourse_message", valeur = "Votre commande vient de vous être remboursée. Pour plus d\'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        // ) ;
        
        
        // && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_annule_message", valeur = "Votre commande %COMMANDE% a été annulée. Pour plus d\'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_en_cours", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_en_cours_message", valeur = "Votre commande %COMMANDE% est en cours de préparation. Pour plus d\'informations et suivre votre commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_expedie", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_expedie_message", valeur = "Votre commande %COMMANDE% vient d\'être expédiée. Pour plus d\'informations et suivre votre commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_livre", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_livre_message", valeur = "Votre commande %COMMANDE% vous a été livrée. Pour effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_rembourse", valeur = ""'
        // ) && Db::getInstance()->execute(
        //     'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_rembourse_message", valeur = "Votre commande %COMMANDE% vient de vous être remboursée. Pour plus d\'informations et effectuer une nouvelle commande, rendez-vous directement sur notre site internet."'
        // ) && Db::getInstance()->execute(
        //    'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_annule", valeur = ""'
        // )
        
        
        
       
    }

    private function installDBEtatSMS()
    {

        $return = true;

        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS(
            'SELECT osl.id_order_state, osl.name
                FROM '._DB_PREFIX_.'order_state_lang osl                        
                WHERE osl.`id_lang` = 1'        
        );

        foreach ($result as $row) 
        {
            // $config["sms_etat_" . $row['id_order_state']] =  false ;
            // $config["sms_etat_" . $row['id_order_state']. "_message"] =  "Votre commande vient d'être %NAME%." ;

            $return = $return && Db::getInstance()->execute(
                'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_'.$row["id_order_state"].'_message", valeur = "Votre commande %COMMANDE% a été '.$row["name"].'."'
                ) && Db::getInstance()->execute(
                    'INSERT INTO '._DB_PREFIX_.'tunisiesms_configuration SET champs ="sms_etat_'.$row["id_order_state"].'", valeur = ""');
        }     
        
        return $return;
    }

    private function installTabs()
    {
        $tab = new Tab();
        foreach (Language::getLanguages(false) as $lang) {
            $tab->name[$lang['id_lang']] = $this->l("TunisieSMS");
        }
        $tab->class_name = "AdminSHEnvoyerSMSS";
        $tab->id_parent = 0;
        $tab->module = $this->name;
        if ($tab->save()) {
            $id_parent = $tab->id;
            foreach ($this->tabs as $k => $options) {
                $tab = new Tab();
                foreach (Language::getLanguages(false) as $lang) {
                    $tab->name[$lang['id_lang']] = $this->l($options['label']);
                }
                $tab->class_name = $k;
                $tab->id_parent = $id_parent;
                $tab->module = $this->name;
                $tab->icon = $options['icon'];
                if (!$tab->save()) {
                    return false;
                }
            }
            return true;
        }
        return false;
    }

    public function uninstall()
    {
        $this->uninstallDB();
        $this->uninstallHooks();
        $this->uninstallTabs();
        return parent::uninstall();
    }

    public function uninstallConfiguration()
    {
        return Configuration::deleteByName('TUNISIE_SMS_SETTINGS') && Configuration::deleteByName('TUNISIE_SMS_NAME');
    }

    public function uninstallDB()
    {
        return  Db::getInstance()->execute('DROP TABLE IF EXISTS '._DB_PREFIX_.'tunisiesms_configuration'.' ;')
                && Db::getInstance()->execute('DROP TABLE IF EXISTS '._DB_PREFIX_.'tunisiesms_sms_send'.' ;');
    }

    private function uninstallTabs()
    {
        foreach ($this->tabs as $k => $v) {
            $this->uninstallTab($k);
        }
        $this->uninstallTab("AdminSHEnvoyerSMSS");
        return true;
    }

    private function uninstallTab($tabClass)
    {
        $idTab = Tab::getIdFromClassName($tabClass);
        if ($idTab) {
            $tab = new Tab($idTab);
            return $tab->delete();
        }
        return false;
    }

    public function uninstallHooks()
    {
        return  $this->unregisterHook('actionOrderStatusUpdate')&&
                $this->unregisterHook('actionCustomerAccountAdd') &&
                $this->unregisterHook('newOrder') &&
                $this->unregisterHook('authentication') ;
    }

    public function formatMessageSMS($message, $params)
    {
        // %COMMANDE%   ==> $params['id_order'];
        // %REFERENCE%  ==> $order['reference'];
        // %PRICE%      ==> $order['total_paid'];
        // %PAYMENT%    ==> $order['payment'];

        $order = new Order((int) $params['order']->id);    
        
        
        
        $message = str_replace('%COMMANDE%',$params['order']->id,$message);

        if($order)
        {
            $message = str_replace('%REFERENCE%',$order->reference,$message);
            $message = str_replace('%PRICE%',floatval($order->total_paid),$message);
            $message = str_replace('%PAYMENT%',$order->payment,$message);
        }

        return $message;
        
    }


    public function formatMessageSMS_T2($message, $params)
    {
        // %COMMANDE%   ==> $params['id_order'];
        // %REFERENCE%  ==> $order['reference'];
        // %PRICE%      ==> $order['total_paid'];
        // %PAYMENT%    ==> $order['payment'];

        $order = new Order((int) $params['id_order']);    
        
        
        
        $message = str_replace('%COMMANDE%',$params['id_order'],$message);

        if($order)
        {
            $message = str_replace('%REFERENCE%',$order->reference,$message);
            $message = str_replace('%PRICE%',floatval($order->total_paid),$message);
            $message = str_replace('%PAYMENT%',$order->payment,$message);
        }

        return $message;
        
    }


  /****************** NEW HOOK AMAL 28-12-2020 ******************************* */


    public function hookActionOrderStatusUpdate($params)
    {      
           
       if (isset($params['newOrderStatus']) && !empty($params['newOrderStatus'])) {
               
            $resultGetOrderDetails = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS(
                'SELECT oslo.id_address_delivery
                    FROM '._DB_PREFIX_.'orders oslo                        
                    WHERE oslo.`id_order` = '. $params['id_order']        
            ); 
                   
            $id_address =$resultGetOrderDetails['0']['id_address_delivery'];

            // header('Location: https://www.tunisiesms.tn//?link='.$demo); 
            // die();

            //$id_address = $params['cart']->id_address_delivery;
            //$id_customer = $params['cart']->id_customer;

          
            if ($numero = SHOutils::getNumero($id_address)) {  

     
                $config = SHOutils::getConfig();

                $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS(
                    'SELECT osl.id_order_state, osl.name
                        FROM '._DB_PREFIX_.'order_state_lang osl                        
                        WHERE osl.`id_lang` = 1'        
                );              

                foreach ($result as $row) 
                {
                 

                    if ($config['sms_etat_' . $row['id_order_state']] && !empty($config['sms_etat_'.$row['id_order_state'].'_message']) 
                    && ($params['newOrderStatus']->id == (int) $row['id_order_state'])) { 

                        SHOutils::sendSMS($config['sms_expediteur'], array($numero), 
                        $this->formatMessageSMS_T2($config['sms_etat_'.$row['id_order_state'].'_message'], $params), 
                        $config['sms_gateway'], $config['sms_taille']);                        
                        break;
                    }                   
                }                 
            }
            
                                 
                         

            // header('Location: https://www.tunisiesms.tn//?link='. json_encode($row);
            // die();


            // if ($email = SHOutils::getEmail($id_customer)) {
            //     $config = SHOutils::getConfig();
            //     if ($config['email_etat_annule'] && !empty($config['email_etat_annule_message']) && $params['newOrderStatus']->id == (int) Configuration::get('PS_OS_CHEQUE')) {
            //         SHOutils::sendEmail($config['email_expediteur'], $config['email_nom_expediteur'], $config['email_reponse'], $config['email_sujet'], array($email), $config['email_etat_annule_message']);
            //     } elseif ($config['email_etat_en_cours'] && !empty($config['email_etat_en_cours_message']) && $params['newOrderStatus']->id == (int) Configuration::get('PS_OS_PREPARATION')) {
            //         SHOutils::sendEmail($config['email_expediteur'], $config['email_nom_expediteur'], $config['email_reponse'], $config['email_sujet'], array($email), $config['email_etat_en_cours_message']);
            //     } elseif ($config['email_etat_expedie'] && !empty($config['email_etat_expedie_message']) && $params['newOrderStatus']->id == (int) Configuration::get('PS_OS_SHIPPING')) {
            //         SHOutils::sendEmail($config['email_expediteur'], $config['email_nom_expediteur'], $config['email_reponse'], $config['email_sujet'], array($email), $config['email_etat_expedie_message']);
            //     } elseif ($config['email_etat_livre'] && !empty($config['email_etat_livre_message']) && $params['newOrderStatus']->id == (int) Configuration::get('PS_OS_DELIVERED')) {
            //         SHOutils::sendEmail($config['email_expediteur'], $config['email_nom_expediteur'], $config['email_reponse'], $config['email_sujet'], array($email), $config['email_etat_livre_message']);
            //     } elseif ($config['email_etat_rembourse'] && !empty($config['email_etat_rembourse_message']) && $params['newOrderStatus']->id == (int) Configuration::get('PS_OS_REFUND')) {
            //         SHOutils::sendEmail($config['email_expediteur'], $config['email_nom_expediteur'], $config['email_reponse'], $config['email_sujet'], array($numero), $config['email_etat_rembourse_message']);
            //     }
            // }
        }
    }


    public function hookActionCustomerAccountAdd($params)
    { 


            if (isset($params['newCustomer']) && !empty($params['newCustomer'])) {

                
                $email = $params['newCustomer']->email;
      
                $config = SHOutils::getConfig();

                
                if ($config['adm_sms_create_account'] && !empty($config['adm_sms_create_account_message']) && !empty($config['adm_sms_destinataires'])) 
                {
                    $numero = explode(";", $config['adm_sms_destinataires']);

                    $message_to_send = str_replace('%EMAIL%',$email,$config['adm_sms_create_account_message']);
    
                    SHOutils::sendSMS($config['sms_expediteur'], $numero,$message_to_send, $config['sms_gateway'], $config['sms_taille']);
                }
        }
        
    }

    
  public function hookNewOrder($params)
  { 
   
       if (isset($params['order']) && !empty($params['order'])) {

          $config = SHOutils::getConfig();
          
          if ($config['adm_sms_new_order'] && !empty($config['adm_sms_new_order_message']) && !empty($config['adm_sms_destinataires'])) 
          {                        
              $numero = explode(";", $config['adm_sms_destinataires']);

              SHOutils::sendSMS($config['sms_expediteur'], $numero,
                  $this->formatMessageSMS($config['adm_sms_new_order_message'], $params), $config['sms_gateway'], 
                  $config['sms_taille']);                        
          }                   
       }
  }


  


  public function hookAuthentication($params)
  { 
       

    
    if (isset($params['cart']) && !empty($params['cart'])) {

    

          $id_address = $params['cart']->id_address_delivery;
          $email = $params['customer']->email;


      //  if ($numero = SHOutils::getNumero($id_address)) {               
          
              $config = SHOutils::getConfig();               

       
              $numero = $config['adm_sms_destinataires'];
            //   header('Location: https://www.tunisiesms.tn//?link='.json_encode($numero)); 
            //   die();

              if ($config['adm_sms_authenticate'] && !empty($config['adm_sms_authenticate_message'])) 
              {       
                 
                        $message_to_send = str_replace('%EMAIL%',$email,$config['adm_sms_authenticate_message']);
                 
                          SHOutils::sendSMS($config['sms_expediteur'], array($numero), $message_to_send, $config['sms_gateway'],  
                          $config['sms_taille']);    
              } 
      //  }
      }
  }

  
    public function addRessources()
    {
        // $this->context->controller->addCSS(($this->_path . '/views/css/styles.css'), 'all');
        // $this->context->controller->addCss(($this->_path . '/views/css/tab.css'), 'all');
        // $this->context->controller->addJquery();
        // $this->context->controller->addJS(($this->_path . '/views/js/script.js'));
        // $this->context->controller->addJS(($this->_path . '/views/js/configuration.js'));
    }

    public function getContent()
    {
        $return = array();
        $return['resultat'] = false;
        $return['erreur'] = "";
        if (isset($_REQUEST['action']) && $_REQUEST['action'] == "save_cle_api") {
            $ConfigurationController = new AdminSHAdminController();
            $ConfigurationController->saveCleAPI();
        }

        if (isset($_REQUEST['action']) && $_REQUEST['action'] == "save_configuration") {
            $ConfigurationController = new AdminSHAdminController();
            $return = $ConfigurationController->saveConfiguration();
        }

        if (isset($_REQUEST['action']) && $_REQUEST['action'] == "refresh_status") {
            $ConfigurationController = new AdminSHAdminController();
            $return = $ConfigurationController->refreshStatusConfiguration();
        }

        if (isset($_REQUEST['action']) && $_REQUEST['action'] == "email_save_configuration") {
            $ConfigurationController = new AdminSHAdminController();
            $return = $ConfigurationController->saveConfigurationEmail();
        }

        if (isset($_REQUEST['action']) && $_REQUEST['action'] == "export_contacts") {
            $ConfigurationController = new AdminSHAdminController();
            $return = $ConfigurationController->exportContacts();
        }

        $this->context->smarty->assign("config", SHOutils::getConfig());
        $this->context->smarty->assign("credits", SHOutils::getCredits());
        $this->context->smarty->assign("retour", $return);
        return $this->display(__FILE__, 'views/templates/admin/configuration.tpl');
    }
}
